@@ -4,27 +4,25 @@ use FindBin qw($Bin);
 use lib "$Bin/../lib";
 
 use Device::LSM303DLHC;
-
 #use Device::Magnetometer::LSM303DLHC;
 #use Device::Accelerometer::LSM303DLHC;
 
-my $dev = Device::LSM303DLHC->new( I2CBusDevicePath => '/dev/i2c-1' );
+my $dev = Device::LSM303DLHC->new(I2CBusDevicePath => '/dev/i2c-1');
 $dev->Magnetometer->enable();
 $dev->Accelerometer->enable();
 use Data::Dumper;
-my ( $minx, $miny, $minz, $maxx, $maxy, $maxz ) = ( 500, 500, 500, 0, 0, 0 );
-my ( $avg, $avgCount ) = ( 0, 0 );
-while () {
+my ($minx, $miny, $minz, $maxx, $maxy, $maxz) = (500,500,500,0,0,0);
+my ($avg,$avgCount) = (0,0);
+while(){
     my $accelerometer = $dev->Accelerometer->getRawReading();
-
     #my $accelerometer = $dev->Accelerometer->getAccelerationVectorInG();
     #my $accelerometer = $dev->Accelerometer->getAccelerationVectorInMSS();
-    my $compass  = $dev->Magnetometer->getRawReading();
+    my $compass = $dev->Magnetometer->getRawReading();
     my $accAngle = $dev->Accelerometer->getAccelerationVectorAngles();
 
+
     #print "COMPASS: $compass->{x}\t$compass->{y}\t$compass->{z}\t\n";
-    print
-"\tACCELEROMETER: $accelerometer->{x}\t$accelerometer->{y}\t$accelerometer->{z}\t\tCOMPASS: $compass->{x}\t$compass->{y}\t$compass->{z}\t\n";
+    print "\tACCELEROMETER: $accelerometer->{x}\t$accelerometer->{y}\t$accelerometer->{z}\t\tCOMPASS: $compass->{x}\t$compass->{y}\t$compass->{z}\t\n" ;
 
 =head2 
 
@@ -32,6 +30,7 @@ while () {
 
     #print "\tACC_ANGLE: " . Dumper $accAngle ;
 
+
 =head2 
 
     $minx = $accelerometer->{x} < $minx ? $accelerometer->{x} : $minx;
@@ -50,6 +49,7 @@ while () {
 
 =cut
 
+    
     #print 'COMPASS: ' . Dumper {$dev->Magnetometer->getRawReading()};
     #print 'ACCELEROMETER: ' . Dumper {$dev->Accelerometer->getRawReading()};
 }
